What’s New in Bazaar 2.6? — Breezy 3.0.2dev documentation

Table of Contents (3.0.2dev)

# What’s New in Bazaar 2.6?

Bazaar 2.6 has been released on the 27th of July 2013 and marks the start of a new long-term stable series. From here, we will only make bugfix releases on the 2.6 series (2.6.1, etc), while 2.7 will become our new development series.

This document accumulates a high level summary of what’s changed. See the Breezy Release Notes for a full list.

Users are encouraged to upgrade from the other stable series. This document outlines the improvements in Bazaar 2.6 vs Bazaar 2.5. As well as summarizing improvements made to the core product, it highlights enhancements within the broader Bazaar world of potential interest to those upgrading.

Bazaar 2.6.0 is fully compatible both locally and on the network with 2.0, 2.1, 2.2, 2.3, 2.4 and 2.5, and can read and write repositories generated by all previous versions.

## Further information

For more detailed information on the changes made, see the the Breezy Release Notes for:

- the interim bzr milestones

- the plugins you use.

For a summary of changes made in earlier releases, see:

- What’s New in Bazaar 2.1?

- What’s New in Bazaar 2.2?

- What’s New in Bazaar 2.3?

- What’s New in Bazaar 2.4 (Oronsay)

- What’s New in Bazaar 2.5?